@@ -3,7 +3,6 @@
 import logging
 
 from django.contrib import messages
-from django.http import HttpResponseRedirect
 from django.shortcuts import redirect
 from django.template.response import TemplateResponse
 from django.urls import reverse_lazy
@@ -13,7 +12,7 @@ from django.views.decorators.http import require_POST
 from django.views.generic.edit import FormView
 
 from plinth import network
-from plinth.modules import first_boot, networks
+from plinth.modules import names, networks
 from plinth.views import AppView
 
 from .forms import (ConnectionTypeSelectForm, EthernetForm, GenericForm,
@@ -30,6 +29,8 @@ CONNECTION_METHOD_STRINGS = {
     'manual': gettext_lazy('manual'),
     'shared': gettext_lazy('shared'),
     'link-local': gettext_lazy('link-local'),
+    'dhcp': gettext_lazy('dhcp'),
+    'ignore': gettext_lazy('ignore'),
 }
 
 # i18n for device.state
@@ -114,6 +115,16 @@ WIRELESS_MODE_STRINGS = {
     'mesh': gettext_lazy('mesh point'),
 }
 
+# i18n for connection.dns_over_tls
+# https://networkmanager.dev/docs/libnm/latest/NMSettingConnection.html#
+# NMSettingConnectionDnsOverTls
+DNS_OVER_TLS_STRINGS = {
+    'default': gettext_lazy('default'),
+    'no': gettext_lazy('no'),
+    'opportunistic': gettext_lazy('opportunistic'),
+    'yes': gettext_lazy('yes'),
+}
+
 
 class NetworksAppView(AppView):
     """Show networks app main page."""
@@ -149,6 +160,8 @@ def show(request, uuid):
     connection_status = network.get_status_from_connection(connection)
     connection_status['zone_string'] = dict(network.ZONES).get(
         connection_status['zone'], connection_status['zone'])
+    connection_status['dns_over_tls_string'] = DNS_OVER_TLS_STRINGS.get(
+        connection_status['dns_over_tls'], connection_status['dns_over_tls'])
     connection_status['ipv4']['method_string'] = CONNECTION_METHOD_STRINGS.get(
         connection_status['ipv4']['method'],
         connection_status['ipv4']['method'])
@@ -198,7 +211,8 @@ def show(request, uuid):
             'connection': connection_status,
             'active_connection': active_connection_status,
             'device': device_status,
-            'access_point': access_point_status
+            'access_point': access_point_status,
+            'is_resolved_installed': names.is_resolved_installed()
         })
 
 
@@ -248,6 +262,9 @@ def edit(request, uuid):
             form_data['zone'] = 'external'
 
         if settings_connection.get_connection_type() != 'pppoe':
+            form_data['dns_over_tls'] = \
+                settings_connection.get_dns_over_tls().value_nick
+
             settings_ipv4 = connection.get_setting_ip4_config()
             form_data['ipv4_method'] = settings_ipv4.get_method()
             if settings_ipv4.get_num_addresses():
@@ -543,24 +560,6 @@ class NetworkTopologyView(FormView):
         return super().form_valid(form)
 
 
-class NetworkTopologyFirstBootView(NetworkTopologyView):
-    """View for network topology form during first wizard."""
-    template_name = 'network_topology_firstboot.html'
-
-    def get_success_url(self):
-        """Return next fistboot step."""
-        return reverse_lazy(first_boot.next_step())
-
-    def form_valid(self, form):
-        """Mark the first wizard step as done, save value and redirect."""
-        first_boot.mark_step_done('network_topology_wizard')
-        if 'skip' in form.data:
-            first_boot.mark_step_done('router_setup_wizard')
-            return FormView.form_valid(self, form)
-
-        return super().form_valid(form)
-
-
 class RouterConfigurationView(FormView):
     """View for router configuration form."""
     template_name = 'router_configuration_update.html'
@@ -579,32 +578,6 @@ class RouterConfigurationView(FormView):
         return super().form_valid(form)
 
 
-class RouterConfigurationFirstBootView(RouterConfigurationView):
-    """View for router configuration form during first wizard."""
-    template_name = 'router_configuration_firstboot.html'
-
-    def dispatch(self, request, *args, **kwargs):
-        """Don't show wizard step if FreedomBox is not behind a router."""
-        network_topology = networks.get_network_topology_type()
-        if network_topology != 'to_router':
-            first_boot.mark_step_done('router_setup_wizard')
-            return HttpResponseRedirect(reverse_lazy(first_boot.next_step()))
-
-        return super().dispatch(request, *args, *kwargs)
-
-    def get_success_url(self):
-        """Return the next wizard step after this one."""
-        return reverse_lazy(first_boot.next_step())
-
-    def form_valid(self, form):
-        """Mark the first wizard step as done, save value and redirect."""
-        first_boot.mark_step_done('router_setup_wizard')
-        if 'skip' in form.data:
-            return FormView.form_valid(self, form)
-
-        return super().form_valid(form)
-
-
 class InternetConnectionTypeView(FormView):
     """View for Internet connection type form."""
     template_name = 'internet_connectivity_type.html'
@@ -624,20 +597,3 @@ class InternetConnectionTypeView(FormView):
         logger.info('Updating internet connectivity type: %s', type_)
         networks.set_internet_connection_type(type_)
         return super().form_valid(form)
-
-
-class InternetConnectionTypeFirstBootView(InternetConnectionTypeView):
-    """View to show Internet connection type form during first wizard."""
-    template_name = 'internet_connectivity_firstboot.html'
-
-    def get_success_url(self):
-        """Return the next wizard step after this one."""
-        return reverse_lazy(first_boot.next_step())
-
-    def form_valid(self, form):
-        """Mark the first wizard step as done, save value and redirect."""
-        first_boot.mark_step_done('internet_connectivity_type_wizard')
-        if 'skip' in form.data:
-            return FormView.form_valid(self, form)
-
-        return super().form_valid(form)
