@@ -54,32 +54,40 @@ _config_page_title_language_map = {
 
 @pytest.fixture(scope='module', autouse=True)
 def fixture_background(session_browser):
+    """Unset language."""
+    yield
+    functional.login(session_browser)
+    functional.user_set_language(session_browser, _language_codes['None'])
+
+
+@pytest.fixture(scope='function', autouse=True)
+def fixture_login(session_browser):
     """Login."""
     functional.login(session_browser)
-    yield
-    functional.user_set_language(session_browser, _language_codes['None'])
 
 
 def test_create_user(session_browser):
     """Test creating a user."""
-    if functional.user_exists(session_browser, 'alice'):
-        functional.delete_user(session_browser, 'alice')
+    _delete_user(session_browser, 'alice')
 
     functional.create_user(session_browser, 'alice', email='alice@example.com')
     assert functional.user_exists(session_browser, 'alice')
     assert _get_email(session_browser, 'alice') == 'alice@example.com'
 
 
-def test_rename_user(session_browser):
+def test_rename_user(session_browser, host_sudo):
     """Test renaming a user."""
     _non_admin_user_exists(session_browser, 'alice')
-    if functional.user_exists(session_browser, 'bob'):
-        functional.delete_user(session_browser, 'bob')
+    _delete_user(session_browser, 'bob')
 
     _rename_user(session_browser, 'alice', 'bob')
     assert not functional.user_exists(session_browser, 'alice')
     assert functional.user_exists(session_browser, 'bob')
 
+    assert 'cn: bob' in host_sudo.check_output('ldapfinger bob')
+    assert host_sudo.user('bob').gecos == 'bob'
+    assert host_sudo.user('bob').home == '/home/bob'
+
 
 def test_admin_users_can_change_own_ssh_keys(session_browser):
     """Test that admin users can change their own ssh keys."""
@@ -94,7 +102,6 @@ def test_non_admin_users_can_change_own_ssh_keys(session_browser):
                                   'alice')
     _set_ssh_keys(session_browser, 'somekey456')
     assert _get_ssh_keys(session_browser) == 'somekey456'
-    functional.login(session_browser)
 
 
 def test_admin_users_can_change_other_users_ssh_keys(session_browser):
@@ -121,6 +128,26 @@ def test_users_can_connect_passwordless_over_ssh(session_browser,
     _should_connect_passwordless_over_ssh(session_browser, tmp_path_factory)
 
 
+def test_ssh_passwordless_after_user_rename(session_browser, tmp_path_factory):
+    """Test that users can connect passwordless after user is renamed."""
+    username_old = 'bob'
+    username_new = 'bob2'
+    functional.app_enable(session_browser, 'ssh')
+    _non_admin_user_exists(session_browser, username_old,
+                           groups=['freedombox-ssh'])
+    _delete_user(session_browser, username_new)
+    _configure_ssh_keys(session_browser, tmp_path_factory,
+                        username=username_old)
+    _should_connect_passwordless_over_ssh(session_browser, tmp_path_factory,
+                                          username=username_old)
+
+    _rename_user(session_browser, username_old, username_new)
+
+    assert functional.user_exists(session_browser, username_new)
+    _should_connect_passwordless_over_ssh(session_browser, tmp_path_factory,
+                                          username=username_new)
+
+
 def test_users_cannot_connect_passwordless_over_ssh(session_browser,
                                                     tmp_path_factory):
     """Test that users cannot connect passwordless over ssh if the keys aren't
@@ -173,8 +200,6 @@ def test_user_states(session_browser, tmp_path_factory):
     _should_connect_passwordless_over_ssh(session_browser, tmp_path_factory,
                                           username=username)
 
-    functional.login(session_browser)
-
 
 def test_admin_users_can_change_own_password(session_browser):
     """Test that admin users can change their own password."""
@@ -183,7 +208,6 @@ def test_admin_users_can_change_own_password(session_browser):
                                   'testadmin')
     _change_password(session_browser, 'newpassword456')
     _can_log_in_with_password(session_browser, 'testadmin', 'newpassword456')
-    functional.login(session_browser)
 
 
 def test_admin_users_can_change_others_password(session_browser):
@@ -191,7 +215,6 @@ def test_admin_users_can_change_others_password(session_browser):
     _non_admin_user_exists(session_browser, 'alice')
     _change_password(session_browser, 'secretsecret567', username='alice')
     _can_log_in_with_password(session_browser, 'alice', 'secretsecret567')
-    functional.login(session_browser)
 
 
 def test_non_admin_users_can_change_own_password(session_browser):
@@ -201,7 +224,6 @@ def test_non_admin_users_can_change_own_password(session_browser):
                                   'alice')
     _change_password(session_browser, 'newpassword123')
     _can_log_in_with_password(session_browser, 'alice', 'newpassword123')
-    functional.login(session_browser)
 
 
 def test_delete_user(session_browser):
@@ -211,15 +233,19 @@ def test_delete_user(session_browser):
     assert not functional.user_exists(session_browser, 'alice')
 
 
-def _admin_user_exists(session_browser, name):
+def _delete_user(session_browser, name):
+    """Delete a user."""
     if functional.user_exists(session_browser, name):
         functional.delete_user(session_browser, name)
+
+
+def _admin_user_exists(session_browser, name):
+    _delete_user(session_browser, name)
     functional.create_user(session_browser, name, groups=['admin'])
 
 
 def _non_admin_user_exists(session_browser, name, groups=[]):
-    if functional.user_exists(session_browser, name):
-        functional.delete_user(session_browser, name)
+    _delete_user(session_browser, name)
     functional.create_user(session_browser, name, groups=groups)
 
 
